#include "..\script_component.hpp"

/*
 * Function: forge_server_db_fnc_getFromStore
 * Author: J. Schmidt
 * 
 * Description:
 * Retrieves data from a store
 *
 * Arguments:
 * 0: _name - Store name <STRING>
 * 1: _key - Key to retrieve (Optional, get entire store if empty) <STRING>
 * 2: _default - Default value if key not found <ANY>
 * 3: _namespace - Namespace to use (Optional, default: missionNamespace) <NAMESPACE>
 *
 * Return Value:
 * Retrieved data or default value
 */

params [
    ["_name", "", [""]],
    ["_key", "", [""]],
    ["_default", nil],
    ["_namespace", missionNamespace, [missionNamespace]]
];

if (_name isEqualTo "") exitWith {
    ERROR_MSG_1("Invalid store name: %1",_name);
    _default
};

private _stores = _namespace getVariable [QGVAR(stores), createHashMap];
private _store = _stores getOrDefault [_name, createHashMap];

if (_key isEqualTo "") then {
    _store
} else {
    _store getOrDefault [_key, _default]
}