#include "..\script_component.hpp"

/*
 * Function: forge_server_db_fnc_saveToTemp
 * Author: J. Schmidt
 * 
 * Description:
 * Saves data to temporary mission store (not persisted between sessions)
 *
 * Arguments:
 * 0: _name - Store name <STRING>
 * 1: _data - Data to save <HASHMAP, ARRAY, ANY>
 * 2: _key - Key to save under <STRING>
 *
 * Return Value:
 * Success <BOOL>
 */

params [
    ["_name", "", [""]],
    ["_data", nil, [createHashMap, [], "", 0, true]],
    ["_key", "", [""]]
];

private _database = call FUNC(verifyDB);
private _store = _database call ["getStore", [_name]];

if (isNil "_store") then {
    _store = _database call ["createStore", [_name, []]];
};

private _tempStores = missionNamespace getVariable [QGVAR(tempStores), createHashMap];
private _tempStore = _tempStores getOrDefault [_name, createHashMap];

_tempStore set [_key, _data];
_tempStores set [_name, _tempStore];
missionNamespace setVariable [QGVAR(tempStores), _tempStores];

true
